%define anolis_release 3
Name:          dtc
Version:       1.6.1
Release:       %{anolis_release}%{dist}
Summary:       Device Tree Compiler
License:       GPLv2+
URL:           https://devicetree.org/

Source0:       https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.gz

Patch1001:     1001-skip-some-python-test.patch

BuildRequires: gcc make
BuildRequires: flex bison swig
BuildRequires: python3-devel python3-setuptools
Requires:      libfdt = %{version}-%{release}

%description
Devicetree is a data structure for describing hardware. Rather than hard coding
every detail of a device into an operating system, many aspects of the hardware
can be described in a data structure that is passed to the operating system at
boot time. The devicetree is used by OpenFirmware, OpenPOWER Abstraction Layer
(OPAL), Power Architecture Platform Requirements (PAPR) and in the standalone
Flattened Device Tree (FDT) form.

%package -n libfdt
Summary: Device tree library

%description -n libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n libfdt-devel
Summary: Development headers for device tree library
Requires: libfdt = %{version}-%{release}

%description -n libfdt-devel
This package provides development files for libfdt

%package -n libfdt-static
Summary: Static version of device tree library
Requires: libfdt-devel = %{version}-%{release}

%description -n libfdt-static
This package provides the static library of libfdt

%package -n python3-libfdt
Summary: Python 3 bindings for device tree library
%{?python_provide:%python_provide python2-libfdt}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description -n python3-libfdt
This package provides python2 bindings for libfdt

%package doc
Summary: Documents for dtc
Requires: %{name} = %{version}-%{release}

%description doc
Documents for dtc.
Devicetree is a data structure for describing hardware. Rather than hard coding
every detail of a device into an operating system, many aspects of the hardware
can be described in a data structure that is passed to the operating system at
boot time. The devicetree is used by OpenFirmware, OpenPOWER Abstraction Layer
(OPAL), Power Architecture Platform Requirements (PAPR) and in the standalone
Flattened Device Tree (FDT) form.

%prep
%autosetup -p1
sed -i 's/python2/python3/' pylibfdt/setup.py

%build
%{make_build} EXTRA_CFLAGS="$RPM_OPT_FLAGS -Wno-cast-qual -Wno-missing-prototypes" LDFLAGS="$RPM_LD_FLAGS"

%check
make check

%install
%{make_install} EXTRA_CFLAGS="$RPM_OPT_FLAGS -Wno-cast-qual -Wno-missing-prototypes" \
                DESTDIR=$RPM_BUILD_ROOT PREFIX=$RPM_BUILD_ROOT/usr \
                LIBDIR=%{_libdir} BINDIR=%{_bindir} INCLUDEDIR=%{_includedir}

# we don't want ftdump and it conflicts with freetype-demos, so drop it (rhbz 797805)
rm -f $RPM_BUILD_ROOT/%{_bindir}/ftdump

%ldconfig_scriptlets -n libfdt

%generate_compatibility_deps

%files
%license GPL
%{_bindir}/*
%{abidir}/convert-dtsv0-option.list
%{abidir}/dtc-option.list
%{abidir}/fdtdump-option.list
%{abidir}/fdtget-option.list
%{abidir}/fdtoverlay-option.list
%{abidir}/fdtput-option.list

%files -n libfdt
%license GPL
%dir %{abidir}
%{_libdir}/libfdt-%{version}.so
%{abidir}/libfdt-*.dump
%{_libdir}/libfdt.so.*

%files -n libfdt-static
%{_libdir}/libfdt.a

%files -n libfdt-devel
%{_libdir}/libfdt.so
%{_includedir}/*

%files -n python3-libfdt
%{python3_sitearch}/*
%{abidir}/_libfdt.cpython-*-linux-gnu.dump

%files doc
%doc Documentation/manual.txt

%changelog 
* Mon Mar 13 2023 Feng Su <sufeng@linux.alibaba.com> 1.6.1-3
- Correct the location of the dump files

* Mon Jan 16 2023 Feng Su <sufeng@linux.alibaba.com> 1.6.1-2
- add doc package
- add abi/api files
- add make check

* Tue Apr 12 2022 Zhongling He <zhonglingh@linux.alibaba.com> 1.6.1-1
- Init package from upstream v1.6.1
